@@ -1,5 +1,3 @@
-/* $Id: ppp.c,v 1.20 2004/06/18 07:24:58 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/ppp.h>
@@ -82,7 +81,7 @@ get_ISDN_stats (glibtop *server, int *in, int *out)
 
 static gboolean is_ISDN_on (glibtop *server, int *online)
 {
-	FILE *f = 0;
+	FILE *f = NULL;
 	char buffer [BUFSIZ], *p;
 	int i;
 
