@@ -1,7 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -23,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/mem.h>
 
@@ -30,20 +27,16 @@ static const unsigned long _glibtop_sysdeps_mem = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_mem_s (glibtop *server)
 {
-    server->sysdeps.mem = _glibtop_sysdeps_mem;
-
-    return 0;
+	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
 
 /* Provides information about memory usage. */
 
-int
+void
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-    memset (buf, 0, sizeof (glibtop_mem));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_mem));
 }
